/*
   Private context for Richardson iteration
*/

#ifndef __SNES_RICHARDSON_H
#define __SNES_RICHARDSON_H
#include <petsc/private/snesimpl.h>

typedef struct {
  int dummy;
} SNES_NRichardson;

#endif
